InputTextField class

输入文本类型

Inheritance

Constructors

InputTextField({Key? key, String? initialValue, required BaseFormConfig<String?> formConfig, Widget? clearSuffix, int? maxLines, TextInputType? keyboardType, bool obscureText = false, String obscuringCharacter = '•', int? minLines, int? maxLength, ValueChanged<String>? onSubmitted, GestureTapCallback? onTap, VoidCallback? onEditingComplete, List<TextInputFormatter>? inputFormatters, bool errorPredict(String? value)?, bool selectAllOnFocus = false, bool updateValueWhenComposing = false})

Properties

asyncValidator FormeAsyncValidator<String?>?
used to perform an async validation
finalinherited
asyncValidatorDebounce Duration?
not worked when validate manually
finalinherited
autovalidateMode AutovalidateMode
finalinherited
builder FormeFieldBuilder<String?>
finalinherited
decorator FormeFieldDecorator<String?>?
used to decorate field
finalinherited
enabled bool
whether field is enabled,
finalinherited
errorPredict bool Function(String? value)?
是否需要飘红
final
fieldType Type
no setterinherited
focusNode FocusNode?
finalinherited
formConfig BaseFormConfig<String?>
表单配置
finalinherited
hashCode int
The hash code for this object.
no setterinherited
initialValue String?
initial value
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
name String?
field name
finalinherited
onInitialized FormeFieldInitialized<String?>?
called immediately after FormeFieldState.initStatus
finalinherited
onSaved FormeFieldSetter<String?>?
finalinherited
onStatusChanged FormeFieldStatusChanged<String?>?
listen field status change
finalinherited
order int?
used to support Forme.autovalidateByOrder
finalinherited
quietlyValidate bool
quietlyValidate
finalinherited
readOnly bool
finalinherited
requestFocusOnUserInteraction bool
whether request focus when field value changed
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectAllOnFocus bool
final
updateValueWhenComposing bool
whether update value when text input is composing
final
validationFilter FormeFieldValidationFilter<String?>?
used to determine whether perform a validation
finalinherited
validator FormeValidator<String?>?
sync validator
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() InputTextFieldState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited