LeftOpenRange class

左开右闭区间指的是左边的边界值不包括在内,而右边的边界值包括在内 格式为:(min,max] # 取值不包括 min,但包括 max 例如:(1, 2]表示:1 < x <= 2

Inheritance

Constructors

LeftOpenRange({num? min, num? max})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
max num
finalinherited
min num
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

contain(num value) bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited