ReverseClosedRange class

反向闭区间指的是区间边界的两个值包括在内 格式为:(min , max)的反区间 例如:(1, 2)的反区间为:(-∞, 1] U [2, +∞)

Inheritance

Constructors

ReverseClosedRange({num? min, num? max})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
max num
finalinherited
min num
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

contain(num value) bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited